/*
 * This file was generated by orbit-idl-2 - DO NOT EDIT!
 */

#ifndef evolution_calendar_H
#define evolution_calendar_H 1
#include <glib.h>
#define ORBIT_IDL_SERIAL 20
#include <orbit/orbit-types.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/** typedefs **/
#include <bonobo/Bonobo.h>
#if !defined(_GNOME_Evolution_Calendar_CalObj_defined)
#define _GNOME_Evolution_Calendar_CalObj_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_CalObj;
#define GNOME_Evolution_Calendar_CalObj_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObj_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObj_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObj_struct;
#define TC_GNOME_Evolution_Calendar_CalObj ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObj_struct)
#endif
#define GNOME_Evolution_Calendar_CalObj__alloc() ((GNOME_Evolution_Calendar_CalObj *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_CalObj__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'c'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'd'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'r'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'c'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'd'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_0 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_8 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_9 '_'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_10 'c'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_11 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_12 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_13 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_14 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_15 'd'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_16 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_17 'r'
#if !defined(_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_defined)
#define _CORBA_sequence_GNOME_Evolution_Calendar_CalObj_defined 1
typedef CORBA_sequence_CORBA_string CORBA_sequence_GNOME_Evolution_Calendar_CalObj;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_0 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_8 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_9 '_'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_10 'c'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_11 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_12 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_13 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_14 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_15 'd'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_16 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObj__alloc CORBA_sequence_CORBA_string__alloc
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObj__freekids CORBA_sequence_CORBA_string__freekids
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObj_allocbuf CORBA_sequence_CORBA_string_allocbuf
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObj_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObj_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjSeq_defined)
#define _GNOME_Evolution_Calendar_CalObjSeq_defined 1
typedef CORBA_sequence_GNOME_Evolution_Calendar_CalObj GNOME_Evolution_Calendar_CalObjSeq;
#define GNOME_Evolution_Calendar_CalObjSeq_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Calendar_CalObj_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjSeq_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Calendar_CalObj_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjSeq_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjSeq_struct;
#define TC_GNOME_Evolution_Calendar_CalObjSeq ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjSeq_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjSeq__alloc() ((GNOME_Evolution_Calendar_CalObjSeq *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj))
#define GNOME_Evolution_Calendar_CalObjSeq__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj,(m),(d))
#define GNOME_Evolution_Calendar_CalObjSeq_allocbuf(l) ((GNOME_Evolution_Calendar_CalObj*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObj, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'c'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'd'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'r'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'c'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'd'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_stringlist_defined)
#define _GNOME_Evolution_Calendar_stringlist_defined 1
typedef CORBA_sequence_CORBA_string GNOME_Evolution_Calendar_stringlist;
#define GNOME_Evolution_Calendar_stringlist_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_stringlist_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_stringlist_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_stringlist_struct;
#define TC_GNOME_Evolution_Calendar_stringlist ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_stringlist_struct)
#endif
#define GNOME_Evolution_Calendar_stringlist__alloc() ((GNOME_Evolution_Calendar_stringlist *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define GNOME_Evolution_Calendar_stringlist__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define GNOME_Evolution_Calendar_stringlist_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjUID_defined)
#define _GNOME_Evolution_Calendar_CalObjUID_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_CalObjUID;
#define GNOME_Evolution_Calendar_CalObjUID_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjUID_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjUID_struct;
#define TC_GNOME_Evolution_Calendar_CalObjUID ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjUID_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjUID__alloc() ((GNOME_Evolution_Calendar_CalObjUID *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_CalObjUID__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalRecurID_defined)
#define _GNOME_Evolution_Calendar_CalRecurID_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_CalRecurID;
#define GNOME_Evolution_Calendar_CalRecurID_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalRecurID_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalRecurID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalRecurID_struct;
#define TC_GNOME_Evolution_Calendar_CalRecurID ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalRecurID_struct)
#endif
#define GNOME_Evolution_Calendar_CalRecurID__alloc() ((GNOME_Evolution_Calendar_CalRecurID *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_CalRecurID__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'c'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'd'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'r'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'c'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'd'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_StringSeq_defined)
#define _GNOME_Evolution_Calendar_StringSeq_defined 1
typedef CORBA_sequence_CORBA_string GNOME_Evolution_Calendar_StringSeq;
#define GNOME_Evolution_Calendar_StringSeq_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_StringSeq_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_StringSeq_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_StringSeq_struct;
#define TC_GNOME_Evolution_Calendar_StringSeq ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_StringSeq_struct)
#endif
#define GNOME_Evolution_Calendar_StringSeq__alloc() ((GNOME_Evolution_Calendar_StringSeq *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define GNOME_Evolution_Calendar_StringSeq__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define GNOME_Evolution_Calendar_StringSeq_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'c'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'd'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'r'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'c'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'd'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_0 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_8 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_9 '_'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_10 'c'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_11 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_12 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_13 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_14 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_15 'd'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_16 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_17 'r'
#if !defined(_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_defined)
#define _CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_defined 1
typedef CORBA_sequence_CORBA_string CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_0 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_8 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_9 '_'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_10 'c'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_11 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_12 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_13 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_14 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_15 'd'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_16 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID__alloc CORBA_sequence_CORBA_string__alloc
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID__freekids CORBA_sequence_CORBA_string__freekids
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_allocbuf CORBA_sequence_CORBA_string_allocbuf
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjUIDSeq_defined)
#define _GNOME_Evolution_Calendar_CalObjUIDSeq_defined 1
typedef CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID GNOME_Evolution_Calendar_CalObjUIDSeq;
#define GNOME_Evolution_Calendar_CalObjUIDSeq_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjUIDSeq_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjUIDSeq_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjUIDSeq_struct;
#define TC_GNOME_Evolution_Calendar_CalObjUIDSeq ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjUIDSeq_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjUIDSeq__alloc() ((GNOME_Evolution_Calendar_CalObjUIDSeq *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID))
#define GNOME_Evolution_Calendar_CalObjUIDSeq__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID,(m),(d))
#define GNOME_Evolution_Calendar_CalObjUIDSeq_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjUID*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjUID, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjID_defined)
#define _GNOME_Evolution_Calendar_CalObjID_defined 1
typedef struct GNOME_Evolution_Calendar_CalObjID_type GNOME_Evolution_Calendar_CalObjID;
struct GNOME_Evolution_Calendar_CalObjID_type {
GNOME_Evolution_Calendar_CalObjUID uid;
GNOME_Evolution_Calendar_CalRecurID rid;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjID_struct;
#define TC_GNOME_Evolution_Calendar_CalObjID ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjID_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjID__alloc() ((GNOME_Evolution_Calendar_CalObjID *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CalObjID))
#define GNOME_Evolution_Calendar_CalObjID__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CalObjID,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_0 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_8 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_9 '_'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_10 'c'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_11 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_12 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_13 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_14 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_15 'd'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_16 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_17 'r'
#if !defined(_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_defined)
#define _CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_Calendar_CalObjID* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_Calendar_CalObjID;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_0 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_8 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_9 '_'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_10 'c'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_11 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_12 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_13 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_14 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_15 'd'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_16 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjID__alloc() ((CORBA_sequence_GNOME_Evolution_Calendar_CalObjID *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjID__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID,(m),(d))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjID*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID, (l)))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjID*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjIDSeq_defined)
#define _GNOME_Evolution_Calendar_CalObjIDSeq_defined 1
typedef CORBA_sequence_GNOME_Evolution_Calendar_CalObjID GNOME_Evolution_Calendar_CalObjIDSeq;
#define GNOME_Evolution_Calendar_CalObjIDSeq_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjIDSeq_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Calendar_CalObjID_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjIDSeq_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjIDSeq_struct;
#define TC_GNOME_Evolution_Calendar_CalObjIDSeq ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjIDSeq_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjIDSeq__alloc() ((GNOME_Evolution_Calendar_CalObjIDSeq *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID))
#define GNOME_Evolution_Calendar_CalObjIDSeq__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID,(m),(d))
#define GNOME_Evolution_Calendar_CalObjIDSeq_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjID*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjID, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalTimezoneObj_defined)
#define _GNOME_Evolution_Calendar_CalTimezoneObj_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_CalTimezoneObj;
#define GNOME_Evolution_Calendar_CalTimezoneObj_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalTimezoneObj_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObj_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalTimezoneObj_struct;
#define TC_GNOME_Evolution_Calendar_CalTimezoneObj ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalTimezoneObj_struct)
#endif
#define GNOME_Evolution_Calendar_CalTimezoneObj__alloc() ((GNOME_Evolution_Calendar_CalTimezoneObj *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_CalTimezoneObj__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalTimezoneObjUID_defined)
#define _GNOME_Evolution_Calendar_CalTimezoneObjUID_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_CalTimezoneObjUID;
#define GNOME_Evolution_Calendar_CalTimezoneObjUID_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalTimezoneObjUID_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_struct;
#define TC_GNOME_Evolution_Calendar_CalTimezoneObjUID ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalTimezoneObjUID_struct)
#endif
#define GNOME_Evolution_Calendar_CalTimezoneObjUID__alloc() ((GNOME_Evolution_Calendar_CalTimezoneObjUID *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_CalTimezoneObjUID__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalAlarmUID_defined)
#define _GNOME_Evolution_Calendar_CalAlarmUID_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_CalAlarmUID;
#define GNOME_Evolution_Calendar_CalAlarmUID_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalAlarmUID_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalAlarmUID_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalAlarmUID_struct;
#define TC_GNOME_Evolution_Calendar_CalAlarmUID ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalAlarmUID_struct)
#endif
#define GNOME_Evolution_Calendar_CalAlarmUID__alloc() ((GNOME_Evolution_Calendar_CalAlarmUID *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_CalAlarmUID__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjType_defined)
#define _GNOME_Evolution_Calendar_CalObjType_defined 1
typedef CORBA_long GNOME_Evolution_Calendar_CalObjType;
#define GNOME_Evolution_Calendar_CalObjType_marshal(x,y,z) CORBA_long_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjType_demarshal(x,y,z,i) CORBA_long_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjType_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjType_struct;
#define TC_GNOME_Evolution_Calendar_CalObjType ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjType_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjType__alloc() ((GNOME_Evolution_Calendar_CalObjType *)ORBit_small_alloc (TC_CORBA_long))
#define GNOME_Evolution_Calendar_CalObjType__freekids(m,d) ORBit_small_freekids (TC_CORBA_long,(m),(d))
#endif
#ifndef GNOME_Evolution_Calendar_TYPE_EVENT
#define GNOME_Evolution_Calendar_TYPE_EVENT 1
#endif /* !GNOME_Evolution_Calendar_TYPE_EVENT */

#ifndef GNOME_Evolution_Calendar_TYPE_TODO
#define GNOME_Evolution_Calendar_TYPE_TODO 2
#endif /* !GNOME_Evolution_Calendar_TYPE_TODO */

#ifndef GNOME_Evolution_Calendar_TYPE_JOURNAL
#define GNOME_Evolution_Calendar_TYPE_JOURNAL 4
#endif /* !GNOME_Evolution_Calendar_TYPE_JOURNAL */

#ifndef GNOME_Evolution_Calendar_TYPE_ANY
#define GNOME_Evolution_Calendar_TYPE_ANY 7
#endif /* !GNOME_Evolution_Calendar_TYPE_ANY */

#if !defined(_GNOME_Evolution_Calendar_CalObjModType_defined)
#define _GNOME_Evolution_Calendar_CalObjModType_defined 1
typedef CORBA_long GNOME_Evolution_Calendar_CalObjModType;
#define GNOME_Evolution_Calendar_CalObjModType_marshal(x,y,z) CORBA_long_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjModType_demarshal(x,y,z,i) CORBA_long_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjModType_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjModType_struct;
#define TC_GNOME_Evolution_Calendar_CalObjModType ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjModType_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjModType__alloc() ((GNOME_Evolution_Calendar_CalObjModType *)ORBit_small_alloc (TC_CORBA_long))
#define GNOME_Evolution_Calendar_CalObjModType__freekids(m,d) ORBit_small_freekids (TC_CORBA_long,(m),(d))
#endif
#ifndef GNOME_Evolution_Calendar_MOD_THIS
#define GNOME_Evolution_Calendar_MOD_THIS 1
#endif /* !GNOME_Evolution_Calendar_MOD_THIS */

#ifndef GNOME_Evolution_Calendar_MOD_THISANDPRIOR
#define GNOME_Evolution_Calendar_MOD_THISANDPRIOR 2
#endif /* !GNOME_Evolution_Calendar_MOD_THISANDPRIOR */

#ifndef GNOME_Evolution_Calendar_MOD_THISANDFUTURE
#define GNOME_Evolution_Calendar_MOD_THISANDFUTURE 4
#endif /* !GNOME_Evolution_Calendar_MOD_THISANDFUTURE */

#ifndef GNOME_Evolution_Calendar_MOD_ALL
#define GNOME_Evolution_Calendar_MOD_ALL 7
#endif /* !GNOME_Evolution_Calendar_MOD_ALL */

#if !defined(_GNOME_Evolution_Calendar_CalMode_defined)
#define _GNOME_Evolution_Calendar_CalMode_defined 1
typedef CORBA_long GNOME_Evolution_Calendar_CalMode;
#define GNOME_Evolution_Calendar_CalMode_marshal(x,y,z) CORBA_long_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalMode_demarshal(x,y,z,i) CORBA_long_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalMode_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalMode_struct;
#define TC_GNOME_Evolution_Calendar_CalMode ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalMode_struct)
#endif
#define GNOME_Evolution_Calendar_CalMode__alloc() ((GNOME_Evolution_Calendar_CalMode *)ORBit_small_alloc (TC_CORBA_long))
#define GNOME_Evolution_Calendar_CalMode__freekids(m,d) ORBit_small_freekids (TC_CORBA_long,(m),(d))
#endif
#ifndef GNOME_Evolution_Calendar_MODE_LOCAL
#define GNOME_Evolution_Calendar_MODE_LOCAL 1
#endif /* !GNOME_Evolution_Calendar_MODE_LOCAL */

#ifndef GNOME_Evolution_Calendar_MODE_REMOTE
#define GNOME_Evolution_Calendar_MODE_REMOTE 2
#endif /* !GNOME_Evolution_Calendar_MODE_REMOTE */

#ifndef GNOME_Evolution_Calendar_MODE_ANY
#define GNOME_Evolution_Calendar_MODE_ANY 7
#endif /* !GNOME_Evolution_Calendar_MODE_ANY */

#if !defined(_GNOME_Evolution_Calendar_CalObjChangeType_defined)
#define _GNOME_Evolution_Calendar_CalObjChangeType_defined 1
typedef CORBA_long GNOME_Evolution_Calendar_CalObjChangeType;
#define GNOME_Evolution_Calendar_CalObjChangeType_marshal(x,y,z) CORBA_long_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjChangeType_demarshal(x,y,z,i) CORBA_long_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeType_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjChangeType_struct;
#define TC_GNOME_Evolution_Calendar_CalObjChangeType ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjChangeType_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjChangeType__alloc() ((GNOME_Evolution_Calendar_CalObjChangeType *)ORBit_small_alloc (TC_CORBA_long))
#define GNOME_Evolution_Calendar_CalObjChangeType__freekids(m,d) ORBit_small_freekids (TC_CORBA_long,(m),(d))
#endif
#ifndef GNOME_Evolution_Calendar_ADDED
#define GNOME_Evolution_Calendar_ADDED 1
#endif /* !GNOME_Evolution_Calendar_ADDED */

#ifndef GNOME_Evolution_Calendar_MODIFIED
#define GNOME_Evolution_Calendar_MODIFIED 2
#endif /* !GNOME_Evolution_Calendar_MODIFIED */

#ifndef GNOME_Evolution_Calendar_DELETED
#define GNOME_Evolution_Calendar_DELETED 4
#endif /* !GNOME_Evolution_Calendar_DELETED */

#if !defined(_GNOME_Evolution_Calendar_Time_t_defined)
#define _GNOME_Evolution_Calendar_Time_t_defined 1
typedef CORBA_unsigned_long GNOME_Evolution_Calendar_Time_t;
#define GNOME_Evolution_Calendar_Time_t_marshal(x,y,z) CORBA_unsigned_long_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_Time_t_demarshal(x,y,z,i) CORBA_unsigned_long_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Time_t_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Time_t_struct;
#define TC_GNOME_Evolution_Calendar_Time_t ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_Time_t_struct)
#endif
#define GNOME_Evolution_Calendar_Time_t__alloc() ((GNOME_Evolution_Calendar_Time_t *)ORBit_small_alloc (TC_CORBA_unsigned_long))
#define GNOME_Evolution_Calendar_Time_t__freekids(m,d) ORBit_small_freekids (TC_CORBA_unsigned_long,(m),(d))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjInstance_defined)
#define _GNOME_Evolution_Calendar_CalObjInstance_defined 1
typedef struct GNOME_Evolution_Calendar_CalObjInstance_type GNOME_Evolution_Calendar_CalObjInstance;
struct GNOME_Evolution_Calendar_CalObjInstance_type {
GNOME_Evolution_Calendar_CalObjUID uid;
GNOME_Evolution_Calendar_Time_t start;
GNOME_Evolution_Calendar_Time_t end;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstance_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjInstance_struct;
#define TC_GNOME_Evolution_Calendar_CalObjInstance ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjInstance_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjInstance__alloc() ((GNOME_Evolution_Calendar_CalObjInstance *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CalObjInstance))
#define GNOME_Evolution_Calendar_CalObjInstance__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CalObjInstance,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_0 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_8 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_9 '_'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_10 'c'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_11 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_12 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_13 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_14 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_15 'd'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_16 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_17 'r'
#if !defined(_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_defined)
#define _CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_Calendar_CalObjInstance* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_0 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_8 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_9 '_'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_10 'c'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_11 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_12 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_13 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_14 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_15 'd'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_16 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance__alloc() ((CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance,(m),(d))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjInstance*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance, (l)))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjInstance*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjInstanceSeq_defined)
#define _GNOME_Evolution_Calendar_CalObjInstanceSeq_defined 1
typedef CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance GNOME_Evolution_Calendar_CalObjInstanceSeq;
#define GNOME_Evolution_Calendar_CalObjInstanceSeq_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjInstanceSeq_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_struct;
#define TC_GNOME_Evolution_Calendar_CalObjInstanceSeq ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjInstanceSeq_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjInstanceSeq__alloc() ((GNOME_Evolution_Calendar_CalObjInstanceSeq *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance))
#define GNOME_Evolution_Calendar_CalObjInstanceSeq__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance,(m),(d))
#define GNOME_Evolution_Calendar_CalObjInstanceSeq_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjInstance*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjInstance, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjChange_defined)
#define _GNOME_Evolution_Calendar_CalObjChange_defined 1
typedef struct GNOME_Evolution_Calendar_CalObjChange_type GNOME_Evolution_Calendar_CalObjChange;
struct GNOME_Evolution_Calendar_CalObjChange_type {
GNOME_Evolution_Calendar_CalObj calobj;
GNOME_Evolution_Calendar_CalObjChangeType type;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChange_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjChange_struct;
#define TC_GNOME_Evolution_Calendar_CalObjChange ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjChange_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjChange__alloc() ((GNOME_Evolution_Calendar_CalObjChange *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CalObjChange))
#define GNOME_Evolution_Calendar_CalObjChange__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CalObjChange,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_0 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_8 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_9 '_'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_10 'c'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_11 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_12 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_13 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_14 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_15 'd'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_16 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_17 'r'
#if !defined(_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_defined)
#define _CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; GNOME_Evolution_Calendar_CalObjChange* _buffer; CORBA_boolean _release; } CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_0 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_8 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_9 '_'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_10 'c'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_11 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_12 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_13 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_14 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_15 'd'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_16 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange__alloc() ((CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange,(m),(d))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjChange*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange, (l)))
#define CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjChange*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CalObjChangeSeq_defined)
#define _GNOME_Evolution_Calendar_CalObjChangeSeq_defined 1
typedef CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange GNOME_Evolution_Calendar_CalObjChangeSeq;
#define GNOME_Evolution_Calendar_CalObjChangeSeq_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CalObjChangeSeq_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalObjChangeSeq_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalObjChangeSeq_struct;
#define TC_GNOME_Evolution_Calendar_CalObjChangeSeq ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalObjChangeSeq_struct)
#endif
#define GNOME_Evolution_Calendar_CalObjChangeSeq__alloc() ((GNOME_Evolution_Calendar_CalObjChangeSeq *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange))
#define GNOME_Evolution_Calendar_CalObjChangeSeq__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange,(m),(d))
#define GNOME_Evolution_Calendar_CalObjChangeSeq_allocbuf(l) ((GNOME_Evolution_Calendar_CalObjChange*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_CalObjChange, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_User_defined)
#define _GNOME_Evolution_Calendar_User_defined 1
typedef CORBA_string GNOME_Evolution_Calendar_User;
#define GNOME_Evolution_Calendar_User_marshal(x,y,z) CORBA_string_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_User_demarshal(x,y,z,i) CORBA_string_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_User_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_User_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_User_struct;
#define TC_GNOME_Evolution_Calendar_User ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_User_struct)
#endif
#define GNOME_Evolution_Calendar_User__alloc() ((GNOME_Evolution_Calendar_User *)ORBit_small_alloc (TC_CORBA_string))
#define GNOME_Evolution_Calendar_User__freekids(m,d) ORBit_small_freekids (TC_CORBA_string,(m),(d))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_CORBA_string)
#define ORBIT_DECL_CORBA_sequence_CORBA_string 1
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_0 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_1 'v'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_2 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_3 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_4 'u'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_5 't'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_6 'i'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_7 'o'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_8 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_9 '_'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_10 'c'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_11 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_12 'l'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_13 'e'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_14 'n'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_15 'd'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_16 'a'
#define ORBIT_IMPL_CORBA_sequence_CORBA_string_17 'r'
#if !defined(_CORBA_sequence_CORBA_string_defined)
#define _CORBA_sequence_CORBA_string_defined 1
typedef struct { CORBA_unsigned_long _maximum, _length; CORBA_string* _buffer; CORBA_boolean _release; } CORBA_sequence_CORBA_string;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_CORBA_string_0)
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_0 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_1 'v'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_2 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_3 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_4 'u'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_5 't'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_6 'i'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_7 'o'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_8 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_9 '_'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_10 'c'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_11 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_12 'l'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_13 'e'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_14 'n'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_15 'd'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_16 'a'
#define TC_IMPL_TC_CORBA_sequence_CORBA_string_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct;
#define TC_CORBA_sequence_CORBA_string ((CORBA_TypeCode)&TC_CORBA_sequence_CORBA_string_struct)
#endif
#define CORBA_sequence_CORBA_string__alloc() ((CORBA_sequence_CORBA_string *)ORBit_small_alloc (TC_CORBA_sequence_CORBA_string))
#define CORBA_sequence_CORBA_string__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_CORBA_string,(m),(d))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#define CORBA_sequence_CORBA_string_allocbuf(l) ((CORBA_string*)ORBit_small_allocbuf (TC_CORBA_sequence_CORBA_string, (l)))
#endif
#if !defined(ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_User)
#define ORBIT_DECL_CORBA_sequence_GNOME_Evolution_Calendar_User 1
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_0 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_1 'v'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_2 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_3 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_4 'u'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_5 't'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_6 'i'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_7 'o'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_8 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_9 '_'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_10 'c'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_11 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_12 'l'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_13 'e'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_14 'n'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_15 'd'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_16 'a'
#define ORBIT_IMPL_CORBA_sequence_GNOME_Evolution_Calendar_User_17 'r'
#if !defined(_CORBA_sequence_GNOME_Evolution_Calendar_User_defined)
#define _CORBA_sequence_GNOME_Evolution_Calendar_User_defined 1
typedef CORBA_sequence_CORBA_string CORBA_sequence_GNOME_Evolution_Calendar_User;
#endif
#if !defined(TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_0)
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_0 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_1 'v'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_2 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_3 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_4 'u'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_5 't'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_6 'i'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_7 'o'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_8 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_9 '_'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_10 'c'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_11 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_12 'l'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_13 'e'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_14 'n'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_15 'd'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_16 'a'
#define TC_IMPL_TC_CORBA_sequence_GNOME_Evolution_Calendar_User_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_GNOME_Evolution_Calendar_User_struct;
#define TC_CORBA_sequence_GNOME_Evolution_Calendar_User ((CORBA_TypeCode)&TC_CORBA_sequence_GNOME_Evolution_Calendar_User_struct)
#endif
#define CORBA_sequence_GNOME_Evolution_Calendar_User__alloc CORBA_sequence_CORBA_string__alloc
#define CORBA_sequence_GNOME_Evolution_Calendar_User__freekids CORBA_sequence_CORBA_string__freekids
#define CORBA_sequence_GNOME_Evolution_Calendar_User_allocbuf CORBA_sequence_CORBA_string_allocbuf
#define CORBA_sequence_GNOME_Evolution_Calendar_User_marshal(x,y,z) CORBA_sequence_CORBA_string_marshal((x),(y),(z))
#define CORBA_sequence_GNOME_Evolution_Calendar_User_demarshal(x,y,z,i) CORBA_sequence_CORBA_string_demarshal((x),(y),(z),(i))
#endif
#if !defined(_GNOME_Evolution_Calendar_UserList_defined)
#define _GNOME_Evolution_Calendar_UserList_defined 1
typedef CORBA_sequence_GNOME_Evolution_Calendar_User GNOME_Evolution_Calendar_UserList;
#define GNOME_Evolution_Calendar_UserList_marshal(x,y,z) CORBA_sequence_GNOME_Evolution_Calendar_User_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_UserList_demarshal(x,y,z,i) CORBA_sequence_GNOME_Evolution_Calendar_User_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_UserList_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_UserList_struct;
#define TC_GNOME_Evolution_Calendar_UserList ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_UserList_struct)
#endif
#define GNOME_Evolution_Calendar_UserList__alloc() ((GNOME_Evolution_Calendar_UserList *)ORBit_small_alloc (TC_CORBA_sequence_GNOME_Evolution_Calendar_User))
#define GNOME_Evolution_Calendar_UserList__freekids(m,d) ORBit_small_freekids (TC_CORBA_sequence_GNOME_Evolution_Calendar_User,(m),(d))
#define GNOME_Evolution_Calendar_UserList_allocbuf(l) ((GNOME_Evolution_Calendar_User*)ORBit_small_allocbuf (TC_CORBA_sequence_GNOME_Evolution_Calendar_User, (l)))
#endif
#if !defined(_GNOME_Evolution_Calendar_CallStatus_defined)
#define _GNOME_Evolution_Calendar_CallStatus_defined 1
typedef enum {
  GNOME_Evolution_Calendar_Success,
  GNOME_Evolution_Calendar_RepositoryOffline,
  GNOME_Evolution_Calendar_PermissionDenied,
  GNOME_Evolution_Calendar_InvalidRange,
  GNOME_Evolution_Calendar_ObjectNotFound,
  GNOME_Evolution_Calendar_InvalidObject,
  GNOME_Evolution_Calendar_ObjectIdAlreadyExists,
  GNOME_Evolution_Calendar_AuthenticationFailed,
  GNOME_Evolution_Calendar_AuthenticationRequired,
  GNOME_Evolution_Calendar_UnsupportedField,
  GNOME_Evolution_Calendar_UnsupportedMethod,
  GNOME_Evolution_Calendar_UnsupportedAuthenticationMethod,
  GNOME_Evolution_Calendar_TLSNotAvailable,
  GNOME_Evolution_Calendar_NoSuchCal,
  GNOME_Evolution_Calendar_UnknownUser,
  GNOME_Evolution_Calendar_OfflineUnavailable,
  GNOME_Evolution_Calendar_SearchSizeLimitExceeded,
  GNOME_Evolution_Calendar_SearchTimeLimitExceeded,
  GNOME_Evolution_Calendar_InvalidQuery,
  GNOME_Evolution_Calendar_QueryRefused,
  GNOME_Evolution_Calendar_CouldNotCancel,
  GNOME_Evolution_Calendar_OtherError,
  GNOME_Evolution_Calendar_InvalidServerVersion
} GNOME_Evolution_Calendar_CallStatus;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CallStatus_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CallStatus_struct;
#define TC_GNOME_Evolution_Calendar_CallStatus ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CallStatus_struct)
#endif
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_CalView) && !defined(_GNOME_Evolution_Calendar_CalView_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_CalView 1
#define _GNOME_Evolution_Calendar_CalView_defined 1
#define GNOME_Evolution_Calendar_CalView__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_CalView;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_CalView__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalView_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalView_struct;
#define TC_GNOME_Evolution_Calendar_CalView ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalView_struct)
#endif
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_CalViewListener) && !defined(_GNOME_Evolution_Calendar_CalViewListener_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_CalViewListener 1
#define _GNOME_Evolution_Calendar_CalViewListener_defined 1
#define GNOME_Evolution_Calendar_CalViewListener__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_CalViewListener;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_CalViewListener__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalViewListener_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalViewListener_struct;
#define TC_GNOME_Evolution_Calendar_CalViewListener ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalViewListener_struct)
#endif
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_Cal) && !defined(_GNOME_Evolution_Calendar_Cal_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_Cal 1
#define _GNOME_Evolution_Calendar_Cal_defined 1
#define GNOME_Evolution_Calendar_Cal__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_Cal;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_Cal__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Cal_struct;
#define TC_GNOME_Evolution_Calendar_Cal ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_Cal_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Calendar_Cal_NotFound
#define ex_GNOME_Evolution_Calendar_Cal_NotFound "IDL:GNOME/Evolution/Calendar/Cal/NotFound:1.0"
#if !defined(_GNOME_Evolution_Calendar_Cal_NotFound_defined)
#define _GNOME_Evolution_Calendar_Cal_NotFound_defined 1
typedef struct GNOME_Evolution_Calendar_Cal_NotFound_type GNOME_Evolution_Calendar_Cal_NotFound;
struct GNOME_Evolution_Calendar_Cal_NotFound_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_NotFound_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Cal_NotFound_struct;
#define TC_GNOME_Evolution_Calendar_Cal_NotFound ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_Cal_NotFound_struct)
#endif
#define GNOME_Evolution_Calendar_Cal_NotFound__alloc() ((GNOME_Evolution_Calendar_Cal_NotFound *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_Cal_NotFound))
#define GNOME_Evolution_Calendar_Cal_NotFound__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_Cal_NotFound,(m),(d))
#endif
#undef ex_GNOME_Evolution_Calendar_Cal_InvalidRange
#define ex_GNOME_Evolution_Calendar_Cal_InvalidRange "IDL:GNOME/Evolution/Calendar/Cal/InvalidRange:1.0"
#if !defined(_GNOME_Evolution_Calendar_Cal_InvalidRange_defined)
#define _GNOME_Evolution_Calendar_Cal_InvalidRange_defined 1
typedef struct GNOME_Evolution_Calendar_Cal_InvalidRange_type GNOME_Evolution_Calendar_Cal_InvalidRange;
struct GNOME_Evolution_Calendar_Cal_InvalidRange_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_Cal_InvalidRange_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_Cal_InvalidRange_struct;
#define TC_GNOME_Evolution_Calendar_Cal_InvalidRange ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_Cal_InvalidRange_struct)
#endif
#define GNOME_Evolution_Calendar_Cal_InvalidRange__alloc() ((GNOME_Evolution_Calendar_Cal_InvalidRange *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_Cal_InvalidRange))
#define GNOME_Evolution_Calendar_Cal_InvalidRange__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_Cal_InvalidRange,(m),(d))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_CalListener) && !defined(_GNOME_Evolution_Calendar_CalListener_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_CalListener 1
#define _GNOME_Evolution_Calendar_CalListener_defined 1
#define GNOME_Evolution_Calendar_CalListener__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_CalListener;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_CalListener__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalListener_struct;
#define TC_GNOME_Evolution_Calendar_CalListener ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalListener_struct)
#endif
#endif
#if !defined(_GNOME_Evolution_Calendar_CalListener_SetModeStatus_defined)
#define _GNOME_Evolution_Calendar_CalListener_SetModeStatus_defined 1
typedef enum {
  GNOME_Evolution_Calendar_CalListener_MODE_SET,
  GNOME_Evolution_Calendar_CalListener_MODE_NOT_SET,
  GNOME_Evolution_Calendar_CalListener_MODE_NOT_SUPPORTED
} GNOME_Evolution_Calendar_CalListener_SetModeStatus;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_struct;
#define TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalListener_SetModeStatus_struct)
#endif
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_CalFactory) && !defined(_GNOME_Evolution_Calendar_CalFactory_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_CalFactory 1
#define _GNOME_Evolution_Calendar_CalFactory_defined 1
#define GNOME_Evolution_Calendar_CalFactory__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_CalFactory;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_CalFactory__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_struct;
#define TC_GNOME_Evolution_Calendar_CalFactory ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalFactory_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Calendar_CalFactory_NilListener
#define ex_GNOME_Evolution_Calendar_CalFactory_NilListener "IDL:GNOME/Evolution/Calendar/CalFactory/NilListener:1.0"
#if !defined(_GNOME_Evolution_Calendar_CalFactory_NilListener_defined)
#define _GNOME_Evolution_Calendar_CalFactory_NilListener_defined 1
typedef struct GNOME_Evolution_Calendar_CalFactory_NilListener_type GNOME_Evolution_Calendar_CalFactory_NilListener;
struct GNOME_Evolution_Calendar_CalFactory_NilListener_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_NilListener_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_NilListener_struct;
#define TC_GNOME_Evolution_Calendar_CalFactory_NilListener ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalFactory_NilListener_struct)
#endif
#define GNOME_Evolution_Calendar_CalFactory_NilListener__alloc() ((GNOME_Evolution_Calendar_CalFactory_NilListener *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CalFactory_NilListener))
#define GNOME_Evolution_Calendar_CalFactory_NilListener__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CalFactory_NilListener,(m),(d))
#endif
#undef ex_GNOME_Evolution_Calendar_CalFactory_InvalidURI
#define ex_GNOME_Evolution_Calendar_CalFactory_InvalidURI "IDL:GNOME/Evolution/Calendar/CalFactory/InvalidURI:1.0"
#if !defined(_GNOME_Evolution_Calendar_CalFactory_InvalidURI_defined)
#define _GNOME_Evolution_Calendar_CalFactory_InvalidURI_defined 1
typedef struct GNOME_Evolution_Calendar_CalFactory_InvalidURI_type GNOME_Evolution_Calendar_CalFactory_InvalidURI;
struct GNOME_Evolution_Calendar_CalFactory_InvalidURI_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_struct;
#define TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI_struct)
#endif
#define GNOME_Evolution_Calendar_CalFactory_InvalidURI__alloc() ((GNOME_Evolution_Calendar_CalFactory_InvalidURI *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI))
#define GNOME_Evolution_Calendar_CalFactory_InvalidURI__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CalFactory_InvalidURI,(m),(d))
#endif
#undef ex_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod
#define ex_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod "IDL:GNOME/Evolution/Calendar/CalFactory/UnsupportedMethod:1.0"
#if !defined(_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_defined)
#define _GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_defined 1
typedef struct GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_type GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod;
struct GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_struct;
#define TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod_struct)
#endif
#define GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod__alloc() ((GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod))
#define GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod,(m),(d))
#endif
#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_CompEditorFactory) && !defined(_GNOME_Evolution_Calendar_CompEditorFactory_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_CompEditorFactory 1
#define _GNOME_Evolution_Calendar_CompEditorFactory_defined 1
#define GNOME_Evolution_Calendar_CompEditorFactory__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_CompEditorFactory;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_CompEditorFactory__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_struct;
#define TC_GNOME_Evolution_Calendar_CompEditorFactory ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CompEditorFactory_struct)
#endif
#endif
#undef ex_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI
#define ex_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI "IDL:GNOME/Evolution/Calendar/CompEditorFactory/InvalidURI:1.0"
#if !defined(_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_defined)
#define _GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_defined 1
typedef struct GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_type GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI;
struct GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_struct;
#define TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI_struct)
#endif
#define GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI__alloc() ((GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI))
#define GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CompEditorFactory_InvalidURI,(m),(d))
#endif
#undef ex_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError
#define ex_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError "IDL:GNOME/Evolution/Calendar/CompEditorFactory/BackendContactError:1.0"
#if !defined(_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_defined)
#define _GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_defined 1
typedef struct GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_type GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError;
struct GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_struct;
#define TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError_struct)
#endif
#define GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError__alloc() ((GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError))
#define GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CompEditorFactory_BackendContactError,(m),(d))
#endif
#undef ex_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType
#define ex_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType "IDL:GNOME/Evolution/Calendar/CompEditorFactory/UnsupportedType:1.0"
#if !defined(_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_defined)
#define _GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_defined 1
typedef struct GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_type GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType;
struct GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_type {
int dummy;
};

#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_struct;
#define TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType_struct)
#endif
#define GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType__alloc() ((GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType *)ORBit_small_alloc (TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType))
#define GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType__freekids(m,d) ORBit_small_freekids (TC_GNOME_Evolution_Calendar_CompEditorFactory_UnsupportedType,(m),(d))
#endif
#if !defined(_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_defined)
#define _GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_defined 1
typedef CORBA_long GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode;
#define GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_marshal(x,y,z) CORBA_long_marshal((x),(y),(z))
#define GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_demarshal(x,y,z,i) CORBA_long_demarshal((x),(y),(z),(i))
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_struct;
#define TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode_struct)
#endif
#define GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode__alloc() ((GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode *)ORBit_small_alloc (TC_CORBA_long))
#define GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode__freekids(m,d) ORBit_small_freekids (TC_CORBA_long,(m),(d))
#endif
#ifndef GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_EVENT
#define GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_EVENT 1
#endif /* !GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_EVENT */

#ifndef GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_ALLDAY_EVENT
#define GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_ALLDAY_EVENT 2
#endif /* !GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_ALLDAY_EVENT */

#ifndef GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_MEETING
#define GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_MEETING 4
#endif /* !GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_MEETING */

#ifndef GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_TODO
#define GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_TODO 8
#endif /* !GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_TODO */

#if !defined(ORBIT_DECL_GNOME_Evolution_Calendar_AlarmNotify) && !defined(_GNOME_Evolution_Calendar_AlarmNotify_defined)
#define ORBIT_DECL_GNOME_Evolution_Calendar_AlarmNotify 1
#define _GNOME_Evolution_Calendar_AlarmNotify_defined 1
#define GNOME_Evolution_Calendar_AlarmNotify__freekids CORBA_Object__freekids
typedef CORBA_Object GNOME_Evolution_Calendar_AlarmNotify;
extern CORBA_unsigned_long GNOME_Evolution_Calendar_AlarmNotify__classid;
#if !defined(TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_0)
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_0 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_1 'v'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_2 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_3 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_4 'u'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_5 't'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_6 'i'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_7 'o'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_8 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_9 '_'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_10 'c'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_11 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_12 'l'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_13 'e'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_14 'n'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_15 'd'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_16 'a'
#define TC_IMPL_TC_GNOME_Evolution_Calendar_AlarmNotify_17 'r'
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static
#else
extern
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_GNOME_Evolution_Calendar_AlarmNotify_struct;
#define TC_GNOME_Evolution_Calendar_AlarmNotify ((CORBA_TypeCode)&TC_GNOME_Evolution_Calendar_AlarmNotify_struct)
#endif
#endif

/** POA structures **/
#ifndef _defined_POA_GNOME_Evolution_Calendar_CalView
#define _defined_POA_GNOME_Evolution_Calendar_CalView 1
typedef struct {
  void *_private;
void (*start)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_GNOME_Evolution_Calendar_CalView__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_CalView__epv *GNOME_Evolution_Calendar_CalView_epv;
} POA_GNOME_Evolution_Calendar_CalView__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_CalView__vepv *vepv;
} POA_GNOME_Evolution_Calendar_CalView;
extern void POA_GNOME_Evolution_Calendar_CalView__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_CalView__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_CalView */
#ifndef _defined_POA_GNOME_Evolution_Calendar_CalViewListener
#define _defined_POA_GNOME_Evolution_Calendar_CalViewListener 1
typedef struct {
  void *_private;
void (*notifyObjectsAdded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev);
void (*notifyObjectsModified)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev);
void (*notifyObjectsRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalObjIDSeq* ids, CORBA_Environment *ev);
void (*notifyQueryProgress)(PortableServer_Servant _servant, const CORBA_char * message, const CORBA_short percent, CORBA_Environment *ev);
void (*notifyQueryDone)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
} POA_GNOME_Evolution_Calendar_CalViewListener__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_CalViewListener__epv *GNOME_Evolution_Calendar_CalViewListener_epv;
} POA_GNOME_Evolution_Calendar_CalViewListener__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_CalViewListener__vepv *vepv;
} POA_GNOME_Evolution_Calendar_CalViewListener;
extern void POA_GNOME_Evolution_Calendar_CalViewListener__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_CalViewListener__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_CalViewListener */
#ifndef _defined_POA_GNOME_Evolution_Calendar_Cal
#define _defined_POA_GNOME_Evolution_Calendar_Cal 1
typedef struct {
  void *_private;
CORBA_string (*_get_uri)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*open)(PortableServer_Servant _servant, const CORBA_boolean only_if_exists, const CORBA_char * username, const CORBA_char * password, CORBA_Environment *ev);
void (*remove)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*isReadOnly)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*getStaticCapabilities)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*getCalAddress)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*getAlarmEmailAddress)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*getLdapAttribute)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*setMode)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev);
void (*getDefaultObject)(PortableServer_Servant _servant, CORBA_Environment *ev);
void (*getObject)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev);
void (*getObjectList)(PortableServer_Servant _servant, const CORBA_char * query, CORBA_Environment *ev);
void (*getTimezone)(PortableServer_Servant _servant, const CORBA_char * tzid, CORBA_Environment *ev);
void (*addTimezone)(PortableServer_Servant _servant, const CORBA_char * tz, CORBA_Environment *ev);
void (*setDefaultTimezone)(PortableServer_Servant _servant, const CORBA_char * tz, CORBA_Environment *ev);
void (*getChanges)(PortableServer_Servant _servant, const CORBA_char * change_id, CORBA_Environment *ev);
void (*getFreeBusy)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_UserList* users, const GNOME_Evolution_Calendar_Time_t start, const GNOME_Evolution_Calendar_Time_t end, CORBA_Environment *ev);
void (*discardAlarm)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * auid, CORBA_Environment *ev);
void (*createObject)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev);
void (*modifyObject)(PortableServer_Servant _servant, const CORBA_char * calobj, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev);
void (*removeObject)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev);
void (*getAttachmentList)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev);
void (*receiveObjects)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev);
void (*sendObjects)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev);
void (*getQuery)(PortableServer_Servant _servant, const CORBA_char * sexp, const GNOME_Evolution_Calendar_CalViewListener ql, CORBA_Environment *ev);
} POA_GNOME_Evolution_Calendar_Cal__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_Cal__epv *GNOME_Evolution_Calendar_Cal_epv;
} POA_GNOME_Evolution_Calendar_Cal__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_Cal__vepv *vepv;
} POA_GNOME_Evolution_Calendar_Cal;
extern void POA_GNOME_Evolution_Calendar_Cal__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_Cal__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_Cal */
#ifndef _defined_POA_GNOME_Evolution_Calendar_CalListener
#define _defined_POA_GNOME_Evolution_Calendar_CalListener 1
typedef struct {
  void *_private;
void (*notifyReadOnly)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_boolean read_only, CORBA_Environment *ev);
void (*notifyCalAddress)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev);
void (*notifyAlarmEmailAddress)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev);
void (*notifyLDAPAttribute)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * ldap_attribute, CORBA_Environment *ev);
void (*notifyStaticCapabilities)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * capabilities, CORBA_Environment *ev);
void (*notifyCalOpened)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyCalRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyObjectCreated)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * uid, CORBA_Environment *ev);
void (*notifyObjectModified)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyObjectRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyAlarmDiscarded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyObjectsReceived)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyObjectsSent)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_UserList* users, const CORBA_char * calobj, CORBA_Environment *ev);
void (*notifyDefaultObjectRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev);
void (*notifyObjectRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev);
void (*notifyObjectListRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev);
void (*notifyQuery)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalView query, CORBA_Environment *ev);
void (*notifyTimezoneRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tz, CORBA_Environment *ev);
void (*notifyTimezoneAdded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tzid, CORBA_Environment *ev);
void (*notifyDefaultTimezoneSet)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void (*notifyChanges)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjChangeSeq* changes, CORBA_Environment *ev);
void (*notifyFreeBusy)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjSeq* freebusy, CORBA_Environment *ev);
void (*notifyAttachmentListRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* attachments, CORBA_Environment *ev);
void (*notifyCalSetMode)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalListener_SetModeStatus status, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev);
void (*notifyErrorOccurred)(PortableServer_Servant _servant, const CORBA_char * message, CORBA_Environment *ev);
void (*notifyAuthRequired)(PortableServer_Servant _servant, CORBA_Environment *ev);
} POA_GNOME_Evolution_Calendar_CalListener__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_CalListener__epv *GNOME_Evolution_Calendar_CalListener_epv;
} POA_GNOME_Evolution_Calendar_CalListener__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_CalListener__vepv *vepv;
} POA_GNOME_Evolution_Calendar_CalListener;
extern void POA_GNOME_Evolution_Calendar_CalListener__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_CalListener__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_CalListener */
#ifndef _defined_POA_GNOME_Evolution_Calendar_CalFactory
#define _defined_POA_GNOME_Evolution_Calendar_CalFactory 1
typedef struct {
  void *_private;
GNOME_Evolution_Calendar_Cal (*getCal)(PortableServer_Servant _servant, const CORBA_char * source, const GNOME_Evolution_Calendar_CalObjType type, const GNOME_Evolution_Calendar_CalListener listener, CORBA_Environment *ev);
} POA_GNOME_Evolution_Calendar_CalFactory__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_CalFactory__epv *GNOME_Evolution_Calendar_CalFactory_epv;
} POA_GNOME_Evolution_Calendar_CalFactory__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_CalFactory__vepv *vepv;
} POA_GNOME_Evolution_Calendar_CalFactory;
extern void POA_GNOME_Evolution_Calendar_CalFactory__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_CalFactory__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_CalFactory */
#ifndef _defined_POA_GNOME_Evolution_Calendar_CompEditorFactory
#define _defined_POA_GNOME_Evolution_Calendar_CompEditorFactory 1
typedef struct {
  void *_private;
void (*editExisting)(PortableServer_Servant _servant, const CORBA_char * uri, const CORBA_char * uid, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev);
void (*editNew)(PortableServer_Servant _servant, const CORBA_char * uri, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev);
} POA_GNOME_Evolution_Calendar_CompEditorFactory__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_CompEditorFactory__epv *GNOME_Evolution_Calendar_CompEditorFactory_epv;
} POA_GNOME_Evolution_Calendar_CompEditorFactory__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_CompEditorFactory__vepv *vepv;
} POA_GNOME_Evolution_Calendar_CompEditorFactory;
extern void POA_GNOME_Evolution_Calendar_CompEditorFactory__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_CompEditorFactory__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_CompEditorFactory */
#ifndef _defined_POA_GNOME_Evolution_Calendar_AlarmNotify
#define _defined_POA_GNOME_Evolution_Calendar_AlarmNotify 1
typedef struct {
  void *_private;
} POA_GNOME_Evolution_Calendar_AlarmNotify__epv;
typedef struct {
  PortableServer_ServantBase__epv *_base_epv;
  POA_Bonobo_Unknown__epv *Bonobo_Unknown_epv;
  POA_GNOME_Evolution_Calendar_AlarmNotify__epv *GNOME_Evolution_Calendar_AlarmNotify_epv;
} POA_GNOME_Evolution_Calendar_AlarmNotify__vepv;
typedef struct {
  void *_private;
  POA_GNOME_Evolution_Calendar_AlarmNotify__vepv *vepv;
} POA_GNOME_Evolution_Calendar_AlarmNotify;
extern void POA_GNOME_Evolution_Calendar_AlarmNotify__init(PortableServer_Servant servant, CORBA_Environment *ev);
extern void POA_GNOME_Evolution_Calendar_AlarmNotify__fini(PortableServer_Servant servant, CORBA_Environment *ev);
#endif /* _defined_POA_GNOME_Evolution_Calendar_AlarmNotify */

/** skel prototypes **/
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalView_start(POA_GNOME_Evolution_Calendar_CalView *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_start)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyObjectsAdded(POA_GNOME_Evolution_Calendar_CalViewListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectsAdded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyObjectsModified(POA_GNOME_Evolution_Calendar_CalViewListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectsModified)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyObjectsRemoved(POA_GNOME_Evolution_Calendar_CalViewListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectsRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalObjIDSeq* ids, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyQueryProgress(POA_GNOME_Evolution_Calendar_CalViewListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyQueryProgress)(PortableServer_Servant _servant, const CORBA_char * message, const CORBA_short percent, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalViewListener_notifyQueryDone(POA_GNOME_Evolution_Calendar_CalViewListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyQueryDone)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal__get_uri(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, CORBA_string (*_impl__get_uri)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_open(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_open)(PortableServer_Servant _servant, const CORBA_boolean only_if_exists, const CORBA_char * username, const CORBA_char * password, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_remove(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_remove)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_isReadOnly(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_isReadOnly)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getStaticCapabilities(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getStaticCapabilities)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getCalAddress(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getCalAddress)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getAlarmEmailAddress(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getAlarmEmailAddress)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getLdapAttribute(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getLdapAttribute)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_setMode(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_setMode)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getDefaultObject(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getDefaultObject)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getObject(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getObject)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getObjectList(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getObjectList)(PortableServer_Servant _servant, const CORBA_char * query, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getTimezone(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getTimezone)(PortableServer_Servant _servant, const CORBA_char * tzid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_addTimezone(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_addTimezone)(PortableServer_Servant _servant, const CORBA_char * tz, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_setDefaultTimezone(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_setDefaultTimezone)(PortableServer_Servant _servant, const CORBA_char * tz, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getChanges(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getChanges)(PortableServer_Servant _servant, const CORBA_char * change_id, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getFreeBusy(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getFreeBusy)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_UserList* users, const GNOME_Evolution_Calendar_Time_t start, const GNOME_Evolution_Calendar_Time_t end, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_discardAlarm(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_discardAlarm)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * auid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_createObject(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_createObject)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_modifyObject(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_modifyObject)(PortableServer_Servant _servant, const CORBA_char * calobj, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_removeObject(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_removeObject)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getAttachmentList(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getAttachmentList)(PortableServer_Servant _servant, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_receiveObjects(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_receiveObjects)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_sendObjects(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_sendObjects)(PortableServer_Servant _servant, const CORBA_char * calobj, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_Cal_getQuery(POA_GNOME_Evolution_Calendar_Cal *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_getQuery)(PortableServer_Servant _servant, const CORBA_char * sexp, const GNOME_Evolution_Calendar_CalViewListener ql, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyReadOnly(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyReadOnly)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_boolean read_only, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalAddress(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyCalAddress)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAlarmEmailAddress(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyAlarmEmailAddress)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyLDAPAttribute(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyLDAPAttribute)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * ldap_attribute, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyStaticCapabilities(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyStaticCapabilities)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * capabilities, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalOpened(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyCalOpened)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalRemoved(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyCalRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectCreated(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectCreated)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * uid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectModified(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectModified)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectRemoved(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectRemoved)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAlarmDiscarded(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyAlarmDiscarded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectsReceived(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectsReceived)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectsSent(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectsSent)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_UserList* users, const CORBA_char * calobj, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyDefaultObjectRequested(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyDefaultObjectRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectRequested(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyObjectListRequested(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyObjectListRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyQuery(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyQuery)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalView query, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyTimezoneRequested(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyTimezoneRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tz, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyTimezoneAdded(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyTimezoneAdded)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tzid, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyDefaultTimezoneSet(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyDefaultTimezoneSet)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyChanges(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyChanges)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjChangeSeq* changes, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyFreeBusy(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyFreeBusy)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjSeq* freebusy, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAttachmentListRequested(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyAttachmentListRequested)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* attachments, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyCalSetMode(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyCalSetMode)(PortableServer_Servant _servant, const GNOME_Evolution_Calendar_CalListener_SetModeStatus status, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyErrorOccurred(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyErrorOccurred)(PortableServer_Servant _servant, const CORBA_char * message, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalListener_notifyAuthRequired(POA_GNOME_Evolution_Calendar_CalListener *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_notifyAuthRequired)(PortableServer_Servant _servant, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CalFactory_getCal(POA_GNOME_Evolution_Calendar_CalFactory *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, GNOME_Evolution_Calendar_Cal (*_impl_getCal)(PortableServer_Servant _servant, const CORBA_char * source, const GNOME_Evolution_Calendar_CalObjType type, const GNOME_Evolution_Calendar_CalListener listener, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CompEditorFactory_editExisting(POA_GNOME_Evolution_Calendar_CompEditorFactory *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_editExisting)(PortableServer_Servant _servant, const CORBA_char * uri, const CORBA_char * uid, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev));
void _ORBIT_skel_small_GNOME_Evolution_Calendar_CompEditorFactory_editNew(POA_GNOME_Evolution_Calendar_CompEditorFactory *_ORBIT_servant, gpointer _ORBIT_retval, gpointer *_ORBIT_args, CORBA_Context ctx,CORBA_Environment *ev, void (*_impl_editNew)(PortableServer_Servant _servant, const CORBA_char * uri, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev));

/** stub prototypes **/
#define GNOME_Evolution_Calendar_CalView_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_CalView_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_CalView_queryInterface Bonobo_Unknown_queryInterface
void GNOME_Evolution_Calendar_CalView_start(GNOME_Evolution_Calendar_CalView _obj, CORBA_Environment *ev);
#define GNOME_Evolution_Calendar_CalViewListener_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_CalViewListener_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_CalViewListener_queryInterface Bonobo_Unknown_queryInterface
void GNOME_Evolution_Calendar_CalViewListener_notifyObjectsAdded(GNOME_Evolution_Calendar_CalViewListener _obj, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalViewListener_notifyObjectsModified(GNOME_Evolution_Calendar_CalViewListener _obj, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalViewListener_notifyObjectsRemoved(GNOME_Evolution_Calendar_CalViewListener _obj, const GNOME_Evolution_Calendar_CalObjIDSeq* ids, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalViewListener_notifyQueryProgress(GNOME_Evolution_Calendar_CalViewListener _obj, const CORBA_char * message, const CORBA_short percent, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalViewListener_notifyQueryDone(GNOME_Evolution_Calendar_CalViewListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
#define GNOME_Evolution_Calendar_Cal_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_Cal_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_Cal_queryInterface Bonobo_Unknown_queryInterface
CORBA_string GNOME_Evolution_Calendar_Cal__get_uri(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_open(GNOME_Evolution_Calendar_Cal _obj, const CORBA_boolean only_if_exists, const CORBA_char * username, const CORBA_char * password, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_remove(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_isReadOnly(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getStaticCapabilities(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getCalAddress(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getAlarmEmailAddress(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getLdapAttribute(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_setMode(GNOME_Evolution_Calendar_Cal _obj, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getDefaultObject(GNOME_Evolution_Calendar_Cal _obj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getObject(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getObjectList(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * query, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getTimezone(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * tzid, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_addTimezone(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * tz, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_setDefaultTimezone(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * tz, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getChanges(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * change_id, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getFreeBusy(GNOME_Evolution_Calendar_Cal _obj, const GNOME_Evolution_Calendar_UserList* users, const GNOME_Evolution_Calendar_Time_t start, const GNOME_Evolution_Calendar_Time_t end, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_discardAlarm(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * uid, const CORBA_char * auid, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_createObject(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * calobj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_modifyObject(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * calobj, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_removeObject(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * uid, const CORBA_char * rid, const GNOME_Evolution_Calendar_CalObjModType mod, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getAttachmentList(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * uid, const CORBA_char * rid, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_receiveObjects(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * calobj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_sendObjects(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * calobj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_Cal_getQuery(GNOME_Evolution_Calendar_Cal _obj, const CORBA_char * sexp, const GNOME_Evolution_Calendar_CalViewListener ql, CORBA_Environment *ev);
#define GNOME_Evolution_Calendar_CalListener_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_CalListener_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_CalListener_queryInterface Bonobo_Unknown_queryInterface
void GNOME_Evolution_Calendar_CalListener_notifyReadOnly(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_boolean read_only, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyCalAddress(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyAlarmEmailAddress(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * address, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyLDAPAttribute(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * ldap_attribute, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyStaticCapabilities(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * capabilities, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyCalOpened(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyCalRemoved(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectCreated(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * uid, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectModified(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectRemoved(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyAlarmDiscarded(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectsReceived(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectsSent(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_UserList* users, const CORBA_char * calobj, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyDefaultObjectRequested(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectRequested(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * object, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyObjectListRequested(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* objects, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyQuery(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalView query, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyTimezoneRequested(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tz, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyTimezoneAdded(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const CORBA_char * tzid, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyDefaultTimezoneSet(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyChanges(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjChangeSeq* changes, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyFreeBusy(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_CalObjSeq* freebusy, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyAttachmentListRequested(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CallStatus status, const GNOME_Evolution_Calendar_stringlist* attachments, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyCalSetMode(GNOME_Evolution_Calendar_CalListener _obj, const GNOME_Evolution_Calendar_CalListener_SetModeStatus status, const GNOME_Evolution_Calendar_CalMode mode, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyErrorOccurred(GNOME_Evolution_Calendar_CalListener _obj, const CORBA_char * message, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CalListener_notifyAuthRequired(GNOME_Evolution_Calendar_CalListener _obj, CORBA_Environment *ev);
#define GNOME_Evolution_Calendar_CalFactory_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_CalFactory_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_CalFactory_queryInterface Bonobo_Unknown_queryInterface
GNOME_Evolution_Calendar_Cal GNOME_Evolution_Calendar_CalFactory_getCal(GNOME_Evolution_Calendar_CalFactory _obj, const CORBA_char * source, const GNOME_Evolution_Calendar_CalObjType type, const GNOME_Evolution_Calendar_CalListener listener, CORBA_Environment *ev);
#define GNOME_Evolution_Calendar_CompEditorFactory_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_CompEditorFactory_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_CompEditorFactory_queryInterface Bonobo_Unknown_queryInterface
void GNOME_Evolution_Calendar_CompEditorFactory_editExisting(GNOME_Evolution_Calendar_CompEditorFactory _obj, const CORBA_char * uri, const CORBA_char * uid, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev);
void GNOME_Evolution_Calendar_CompEditorFactory_editNew(GNOME_Evolution_Calendar_CompEditorFactory _obj, const CORBA_char * uri, const GNOME_Evolution_Calendar_CompEditorFactory_CompEditorMode mode, CORBA_Environment *ev);
#define GNOME_Evolution_Calendar_AlarmNotify_ref Bonobo_Unknown_ref
#define GNOME_Evolution_Calendar_AlarmNotify_unref Bonobo_Unknown_unref
#define GNOME_Evolution_Calendar_AlarmNotify_queryInterface Bonobo_Unknown_queryInterface
#include <orbit/orb-core/orbit-interface.h>

#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalView__iinterface;
#define GNOME_Evolution_Calendar_CalView_IMETHODS_LEN 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalView__imethods[GNOME_Evolution_Calendar_CalView_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalViewListener__iinterface;
#define GNOME_Evolution_Calendar_CalViewListener_IMETHODS_LEN 5
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalViewListener__imethods[GNOME_Evolution_Calendar_CalViewListener_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_Cal__iinterface;
#define GNOME_Evolution_Calendar_Cal_IMETHODS_LEN 25
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Calendar_Cal__imethods[GNOME_Evolution_Calendar_Cal_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalListener__iinterface;
#define GNOME_Evolution_Calendar_CalListener_IMETHODS_LEN 26
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalListener__imethods[GNOME_Evolution_Calendar_CalListener_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CalFactory__iinterface;
#define GNOME_Evolution_Calendar_CalFactory_IMETHODS_LEN 1
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CalFactory__imethods[GNOME_Evolution_Calendar_CalFactory_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_CompEditorFactory__iinterface;
#define GNOME_Evolution_Calendar_CompEditorFactory_IMETHODS_LEN 2
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IMethod GNOME_Evolution_Calendar_CompEditorFactory__imethods[GNOME_Evolution_Calendar_CompEditorFactory_IMETHODS_LEN];
#ifdef ORBIT_IDL_C_IMODULE_evolution_calendar
static 
#else
extern 
#endif
ORBit_IInterface GNOME_Evolution_Calendar_AlarmNotify__iinterface;
#define GNOME_Evolution_Calendar_AlarmNotify_IMETHODS_LEN 0
#define GNOME_Evolution_Calendar_AlarmNotify__imethods (ORBit_IMethod*) NULL

/** IMethods index */

#ifndef __GNOME_Evolution_Calendar_CalView__imethods_index
#define __GNOME_Evolution_Calendar_CalView__imethods_index
typedef enum {
	GNOME_Evolution_Calendar_CalView_start__imethods_index
} GNOME_Evolution_Calendar_CalView__imethods_index;
#endif /* __GNOME_Evolution_Calendar_CalView__imethods_index */

#ifndef __GNOME_Evolution_Calendar_CalViewListener__imethods_index
#define __GNOME_Evolution_Calendar_CalViewListener__imethods_index
typedef enum {
	GNOME_Evolution_Calendar_CalViewListener_notifyObjectsAdded__imethods_index,
	GNOME_Evolution_Calendar_CalViewListener_notifyObjectsModified__imethods_index,
	GNOME_Evolution_Calendar_CalViewListener_notifyObjectsRemoved__imethods_index,
	GNOME_Evolution_Calendar_CalViewListener_notifyQueryProgress__imethods_index,
	GNOME_Evolution_Calendar_CalViewListener_notifyQueryDone__imethods_index
} GNOME_Evolution_Calendar_CalViewListener__imethods_index;
#endif /* __GNOME_Evolution_Calendar_CalViewListener__imethods_index */

#ifndef __GNOME_Evolution_Calendar_Cal__imethods_index
#define __GNOME_Evolution_Calendar_Cal__imethods_index
typedef enum {
	GNOME_Evolution_Calendar_Cal__get_uri__imethods_index,
	GNOME_Evolution_Calendar_Cal_open__imethods_index,
	GNOME_Evolution_Calendar_Cal_remove__imethods_index,
	GNOME_Evolution_Calendar_Cal_isReadOnly__imethods_index,
	GNOME_Evolution_Calendar_Cal_getStaticCapabilities__imethods_index,
	GNOME_Evolution_Calendar_Cal_getCalAddress__imethods_index,
	GNOME_Evolution_Calendar_Cal_getAlarmEmailAddress__imethods_index,
	GNOME_Evolution_Calendar_Cal_getLdapAttribute__imethods_index,
	GNOME_Evolution_Calendar_Cal_setMode__imethods_index,
	GNOME_Evolution_Calendar_Cal_getDefaultObject__imethods_index,
	GNOME_Evolution_Calendar_Cal_getObject__imethods_index,
	GNOME_Evolution_Calendar_Cal_getObjectList__imethods_index,
	GNOME_Evolution_Calendar_Cal_getTimezone__imethods_index,
	GNOME_Evolution_Calendar_Cal_addTimezone__imethods_index,
	GNOME_Evolution_Calendar_Cal_setDefaultTimezone__imethods_index,
	GNOME_Evolution_Calendar_Cal_getChanges__imethods_index,
	GNOME_Evolution_Calendar_Cal_getFreeBusy__imethods_index,
	GNOME_Evolution_Calendar_Cal_discardAlarm__imethods_index,
	GNOME_Evolution_Calendar_Cal_createObject__imethods_index,
	GNOME_Evolution_Calendar_Cal_modifyObject__imethods_index,
	GNOME_Evolution_Calendar_Cal_removeObject__imethods_index,
	GNOME_Evolution_Calendar_Cal_getAttachmentList__imethods_index,
	GNOME_Evolution_Calendar_Cal_receiveObjects__imethods_index,
	GNOME_Evolution_Calendar_Cal_sendObjects__imethods_index,
	GNOME_Evolution_Calendar_Cal_getQuery__imethods_index
} GNOME_Evolution_Calendar_Cal__imethods_index;
#endif /* __GNOME_Evolution_Calendar_Cal__imethods_index */

#ifndef __GNOME_Evolution_Calendar_CalListener__imethods_index
#define __GNOME_Evolution_Calendar_CalListener__imethods_index
typedef enum {
	GNOME_Evolution_Calendar_CalListener_notifyReadOnly__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyCalAddress__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyAlarmEmailAddress__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyLDAPAttribute__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyStaticCapabilities__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyCalOpened__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyCalRemoved__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectCreated__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectModified__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectRemoved__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyAlarmDiscarded__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectsReceived__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectsSent__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyDefaultObjectRequested__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectRequested__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyObjectListRequested__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyQuery__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyTimezoneRequested__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyTimezoneAdded__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyDefaultTimezoneSet__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyChanges__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyFreeBusy__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyAttachmentListRequested__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyCalSetMode__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyErrorOccurred__imethods_index,
	GNOME_Evolution_Calendar_CalListener_notifyAuthRequired__imethods_index
} GNOME_Evolution_Calendar_CalListener__imethods_index;
#endif /* __GNOME_Evolution_Calendar_CalListener__imethods_index */

#ifndef __GNOME_Evolution_Calendar_CalFactory__imethods_index
#define __GNOME_Evolution_Calendar_CalFactory__imethods_index
typedef enum {
	GNOME_Evolution_Calendar_CalFactory_getCal__imethods_index
} GNOME_Evolution_Calendar_CalFactory__imethods_index;
#endif /* __GNOME_Evolution_Calendar_CalFactory__imethods_index */

#ifndef __GNOME_Evolution_Calendar_CompEditorFactory__imethods_index
#define __GNOME_Evolution_Calendar_CompEditorFactory__imethods_index
typedef enum {
	GNOME_Evolution_Calendar_CompEditorFactory_editExisting__imethods_index,
	GNOME_Evolution_Calendar_CompEditorFactory_editNew__imethods_index
} GNOME_Evolution_Calendar_CompEditorFactory__imethods_index;
#endif /* __GNOME_Evolution_Calendar_CompEditorFactory__imethods_index */

#ifndef __ORBIT_IMETHODS_INDEX
#define __ORBIT_IMETHODS_INDEX
#define ORBIT_IMETHODS_INDEX(m) (m ## __imethods_index)
#endif /* __ORBIT_IMETHODS_INDEX */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#ifndef EXCLUDE_ORBIT_H
#include <orbit/orbit.h>

#endif /* EXCLUDE_ORBIT_H */
#endif
#undef ORBIT_IDL_SERIAL
